# How do I install Rio?

Rio is available on PyPI, so you can install it using pip:

```bash
pip install rio
```

On some platforms, `pip` isn't available directly in the command line. If you're
running into trouble with the command above, try one of theses alternatives:

```bash
python -m pip install rio
```

```bash
python3 -m pip install rio
```

```bash
py -m pip install rio
```

After this, a `rio` command will be available in your terminal. You can use this
to create new projects, add components to existing ones, and much more. Once
again, if the command for some reason isn't available, you can try running `rio`
through `python`:

```bash
python -m rio
```

```bash
python3 -m rio
```

```bash
py -m rio
```
